@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: x509-system
 version: 1.6.3
-id: x509-system-1.6.3-6ba9c22edd2365d0a08eb6f448807838
-key: x509s_KNkL3i73hVQJleBQzr6DhW
+id: x509-system-1.6.3-c8b329776e9eeee116761552f3bd6b7a
+key: x509s_IHaj5Dmu9YjCBQrl6dCf7c
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-system-1.6.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-system-1.6.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-system-1.6.3
-hs-libraries: HSx509-system-1.6.3-KNkL3i73hVQJleBQzr6DhW
+hs-libraries: HSx509-system-1.6.3-IHaj5Dmu9YjCBQrl6dCf7c
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -31,8 +31,8 @@ depends:
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
-    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
-    x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
+    x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
+    x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
 haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
 haddock-html: /usr/share/doc/haskell-x509-system/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
